import * as eventhub from "@pulumi/azure/eventhub";
import * as pulumi from "@pulumi/pulumi";
import * as subscriptionMod from "../subscription";
interface TopicBinding extends subscriptionMod.Binding {
    /**
     * The name of the property in the context object to bind the actual topic message to.
     */
    name: string;
    /**
     * The type of a topic binding.  Must be 'serviceBusTrigger'.
     */
    type: "serviceBusTrigger";
    /**
     * The direction of the binding.  We only support topics being inputs to functions.
     */
    direction: "in";
    /**
     * The name of the topic we are subscribing to.
     */
    topicName: string;
    /**
     * The name of the subscription inside the topic we are subscribing to.
     */
    subscriptionName: string;
    /**
     * The name of an app setting that contains the Service Bus connection string to use for this binding.
     */
    connection: string;
}
/**
 * Data that will be passed along in the context object to the BlobCallback.
 */
export interface TopicContext extends subscriptionMod.Context {
    invocationId: string;
    executionContext: {
        invocationId: string;
        functionName: string;
        functionDirectory: string;
    };
    bindings: {
        topic: string;
    };
    bindingData: {
        deadLetterSource: any;
        messageId: string;
        contentType: string;
        replyTo: any;
        to: any;
        label: any;
        correlationId: any;
        properties: Record<string, any>;
        topic: string;
        sys: {
            methodName: string;
            utcNow: string;
        };
        invocationId: string;
    };
}
/**
 * Signature of the callback that can receive blob notifications.
 */
export declare type TopicCallback = subscriptionMod.Callback<TopicContext, any>;
export interface TopicEventSubscriptionArgs extends subscriptionMod.EventSubscriptionArgs<TopicContext, any> {
    /**
     * The eventhub.Subscription to subscribe the FunctionApp to.  If not present, a new
     * Subscription resource will be created.
     */
    subscription?: eventhub.Subscription;
    /**
     * The maximum number of deliveries.  Will default to 10 if not specified.
     */
    maxDeliveryCount?: pulumi.Input<number>;
}
/**
 * Creates a new subscription to the given blob using the callback provided, along with optional
 * options to control the behavior of the subscription.
 */
export declare function onTopicEvent(name: string, namespace: eventhub.Namespace, topic: eventhub.Topic, args: TopicEventSubscriptionArgs, opts?: pulumi.ResourceOptions): TopicEventSubscription;
export declare class TopicEventSubscription extends subscriptionMod.EventSubscription<TopicContext, any> {
    readonly namespace: eventhub.Namespace;
    readonly topic: eventhub.Topic;
    readonly subscription: eventhub.Subscription;
    constructor(name: string, namespace: eventhub.Namespace, topic: eventhub.Topic, subscription: eventhub.Subscription, bindings: pulumi.Output<TopicBinding[]>, args: subscriptionMod.EventSubscriptionArgs<TopicContext, any>, options?: pulumi.ResourceOptions);
}
export {};
